@@ -15,17 +15,24 @@ use MooX::StrictConstructor;
 
 my $cli = 0;
 
+=pod
+has debug => (
+    is => 'rw',
+    default => 0,
+);
+=cut
+
 has custom_opt => ( is => 'ro', );
 
 has internal_attr => (
-    is       => 'rw',
-    init_arg => undef,
+    is => 'rw',
+
+    #init_arg => undef,
 );
 
 has cli => (
-    is       => 'lazy',
-    init_arg => undef,
-    default  => sub { return $cli; },
+    is      => 'lazy',
+    default => sub { return $cli; },
 );
 
 # all attributes and package variable MUST be declared before this!
@@ -43,8 +50,6 @@ do {
     exit $app->run;
 } unless caller();
 
-# executable code like this should not be used in actual scripts, this
-# is only here to provide data for the tests.
 print "command line flag not set\n" if !$cli;
 print "exit was not called\n";
 
@@ -53,16 +58,14 @@ print "exit was not called\n";
 sub BUILD {
     my $self = shift;
 
-    # this will trigger the lazy default
-    print "running from command line\n" if $self->cli && $self->verbose;
-
-    return;
+    print "cli: $cli\n" if $self->verbose;
 }
 
 sub run {
     my $self = shift;
 
-    printf( "custom_opt: %s\n", $self->custom_opt ) if $self->custom_opt;
+    print "running from command line\n" if $self->cli;
+    print 'custom_opt: ' . $self->custom_opt . "\n" if $self->custom_opt;
 
     print Dumper($self) if $self->debug;
 
@@ -76,11 +79,11 @@ __END__
 
 =head1 NAME
  
-moodulino.pl - eample showing how to use MooX::Role::CliOptions
+moodulino - eample showing how to use MooX::Role::CliOptions
  
 =head1 SYNOPSIS
  
-moodulino.pl [options]
+moodulino [options]
  
  Options:
    --debug    add diagnostic messages and/or disable database writes
